@@ -85,7 +85,12 @@ def __get_content_images(response, path):
     images_list2 = response.xpath(image_path2).extract()
     images_list2 = list(map(handle_img_set, list(images_list2)))
     images2 = get_img_list(response, images_list2)
-    item_list = list(set(images1 + images2 + images3))
+
+    image_path4 = "{}/descendant::img/@data-src".format(path)
+    images_list4 = response.xpath(image_path4).extract()
+    images4 = get_img_list(response, images_list4)
+
+    item_list = list(set(images1 + images2 + images3 + images4))
     return item_list
 
 
